@@ -1,6 +1,6 @@
 # Copyright 2017 Palantir Technologies, Inc.
 import logging
-from pyls import hookimpl, lsp, uris
+from pyls import hookimpl, lsp
 
 log = logging.getLogger(__name__)
 
@@ -13,7 +13,7 @@ def pyls_document_highlight(document, position):
         return definition.line is not None and definition.column is not None
 
     def local_to_document(definition):
-        return not definition.module_path or uris.uri_with(document.uri, path=definition.module_path) == document.uri
+        return not definition.module_path or definition.module_path == document.path
 
     return [{
         'range': {
