@@ -15,12 +15,10 @@ def pyls_references(document, position, exclude_declaration=False):
         usages = [d for d in usages if not d.is_definition()]
 
     # Filter out builtin modules
-    usages = [d for d in usages if not d.in_builtin_module()]
-
     return [{
         'uri': uris.uri_with(document.uri, path=d.module_path) if d.module_path else document.uri,
         'range': {
             'start': {'line': d.line - 1, 'character': d.column},
             'end': {'line': d.line - 1, 'character': d.column + len(d.name)}
         }
-    } for d in usages]
+    } for d in usages if not d.in_builtin_module()]
